# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class LogprobsEnum(str, enum.Enum):
    ALL = "ALL"
    NONE = "NONE"

    def visit(self, all: typing.Callable[[], T_Result], none: typing.Callable[[], T_Result]) -> T_Result:
        if self is LogprobsEnum.ALL:
            return all()
        if self is LogprobsEnum.NONE:
            return none()
