# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime
from .model_version_sandbox_snapshot import ModelVersionSandboxSnapshot


class ModelVersionBuildConfig(pydantic.BaseModel):
    base_model: str = pydantic.Field(
        description=(
            "The name of the base model used to create this model version, as identified by the LLM provider.\n"
        )
    )
    sandbox_snapshot: typing.Optional[ModelVersionSandboxSnapshot] = pydantic.Field(
        description=(
            "Information about the sandbox snapshot that was used to create this model version, if applicable.\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}
