# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ..core.datetime_utils import serialize_datetime


class Document(pydantic.BaseModel):
    id: str = pydantic.Field(description=("The ID of the document.\n"))
    label: str = pydantic.Field(description=("The human-readable name for the document.\n"))
    external_id: typing.Optional[str] = pydantic.Field(
        description=(
            "The unique ID of the document as represented in an external system and specified when it was originally uploaded.\n"
        )
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}
