# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class VellumEnvironment:
    PRODUCTION: VellumEnvironment

    def __init__(self, *, default: str, predict: str, documents: str):
        self.default = default
        self.predict = predict
        self.documents = documents


VellumEnvironment.PRODUCTION = VellumEnvironment(
    default="https://api.vellum.ai", predict="https://predict.vellum.ai", documents="https://documents.vellum.ai"
)
