# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SlimDocumentStatusEnum(str, enum.Enum):
    ACTIVE = "ACTIVE"

    def visit(self, active: typing.Callable[[], T_Result]) -> T_Result:
        if self is SlimDocumentStatusEnum.ACTIVE:
            return active()
